@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
 **/
 
 
-require_once dirname(__FILE__).'/../../include/hostgroups.inc.php';
 require_once dirname(__FILE__).'/../../include/hosts.inc.php';
 require_once dirname(__FILE__).'/../../include/triggers.inc.php';
 require_once dirname(__FILE__).'/../../include/items.inc.php';
@@ -273,8 +272,7 @@ class CControllerPopupGeneric extends CController {
 					_('Name'),
 					_('Key'),
 					_('Type'),
-					_('Type of information'),
-					_('Status')
+					_('Type of information')
 				]
 			],
 			'sysmaps' => [
@@ -289,18 +287,14 @@ class CControllerPopupGeneric extends CController {
 					_('Name')
 				]
 			],
-			'screens2' => [
-				'title' => _('Screens'),
-				'min_user_type' => USER_TYPE_ZABBIX_USER,
-				'allowed_src_fields' => 'screenid,name',
-				'table_columns' => [
-					_('Name')
-				]
-			],
 			'drules' => [
 				'title' => _('Discovery rules'),
 				'min_user_type' => USER_TYPE_ZABBIX_ADMIN,
 				'allowed_src_fields' => 'druleid,name',
+				'form' => [
+					'name' => 'druleform',
+					'id' => 'drules'
+				],
 				'table_columns' => [
 					_('Name')
 				]
@@ -341,43 +335,46 @@ class CControllerPopupGeneric extends CController {
 		}
 
 		$fields = [
-			'dstfrm' =>						'string|fatal',
-			'dstfld1' =>					'string|not_empty',
-			'srctbl' =>						'string',
-			'srcfld1' =>					'string|required|in '.$this->popup_properties[$this->source_table]['allowed_src_fields'],
-			'groupid' =>					'db hstgrp.groupid',
-			'group' =>						'string',
-			'hostid' =>						'db hosts.hostid',
-			'host' =>						'string',
-			'parent_discoveryid' =>			'db items.itemid',
-			'screenid' =>					'db screens.screenid',
-			'templates' =>					'string|not_empty',
-			'host_templates' =>				'string|not_empty',
-			'multiselect' =>				'in 1',
-			'submit' =>						'string',
-			'excludeids' =>					'array',
-			'disableids' =>					'array',
-			'only_hostid' =>				'db hosts.hostid',
-			'monitored_hosts' =>			'in 1',
-			'templated_hosts' =>			'in 1',
-			'real_hosts' =>					'in 1',
-			'normal_only' =>				'in 1',
-			'with_applications' =>			'in 1',
-			'with_graphs' =>				'in 1',
-			'with_items' =>					'in 1',
-			'with_simple_graph_items' =>	'in 1',
-			'with_triggers' =>				'in 1',
-			'with_monitored_triggers' =>	'in 1',
-			'with_webitems' =>				'in 1',
-			'itemtype' =>					'in '.implode(',', $this->allowed_item_types),
-			'value_types' =>				'array',
-			'numeric' =>					'in 1',
-			'reference' =>					'string',
-			'orig_names' =>					'in 1',
-			'writeonly' =>					'in 1',
-			'noempty' =>					'in 1',
-			'submit_parent' =>				'in 1',
-			'enrich_parent_groups' =>		'in 1'
+			'dstfrm' =>								'string|fatal',
+			'dstfld1' =>							'string|not_empty',
+			'srctbl' =>								'string',
+			'srcfld1' =>							'string|required|in '.$this->popup_properties[$this->source_table]['allowed_src_fields'],
+			'groupid' =>							'db hstgrp.groupid',
+			'group' =>								'string',
+			'hostid' =>								'db hosts.hostid',
+			'host' =>								'string',
+			'parent_discoveryid' =>					'db items.itemid',
+			'screenid' =>							'db screens.screenid',
+			'templates' =>							'string|not_empty',
+			'host_templates' =>						'string|not_empty',
+			'multiselect' =>						'in 1',
+			'patternselect' =>						'in 1',
+			'submit' =>								'string',
+			'excludeids' =>							'array',
+			'disableids' =>							'array',
+			'only_hostid' =>						'db hosts.hostid',
+			'monitored_hosts' =>					'in 1',
+			'templated_hosts' =>					'in 1',
+			'real_hosts' =>							'in 1',
+			'normal_only' =>						'in 1',
+			'with_applications' =>					'in 1',
+			'with_graphs' =>						'in 1',
+			'with_graph_prototypes' =>				'in 1',
+			'with_items' =>							'in 1',
+			'with_simple_graph_items' =>			'in 1',
+			'with_simple_graph_item_prototypes' =>	'in 1',
+			'with_triggers' =>						'in 1',
+			'with_monitored_triggers' =>			'in 1',
+			'with_webitems' =>						'in 1',
+			'itemtype' =>							'in '.implode(',', $this->allowed_item_types),
+			'value_types' =>						'array',
+			'numeric' =>							'in 1',
+			'reference' =>							'string',
+			'orig_names' =>							'in 1',
+			'writeonly' =>							'in 1',
+			'noempty' =>							'in 1',
+			'submit_parent' =>						'in 1',
+			'enrich_parent_groups' =>				'in 1'
 		];
 
 		// Set destination and source field validation roles.
@@ -543,25 +540,14 @@ class CControllerPopupGeneric extends CController {
 			$options['hosts']['templated_hosts'] = true;
 		}
 
-		if ($this->hasInput('with_applications')) {
-			$options['groups']['with_applications'] = true;
-			$options['hosts']['with_applications'] = true;
-		}
-		elseif ($this->hasInput('with_graphs')) {
-			$options['groups']['with_graphs'] = true;
-			$options['hosts']['with_graphs'] = true;
-		}
-		elseif ($this->hasInput('with_simple_graph_items')) {
-			$options['groups']['with_simple_graph_items'] = true;
-			$options['hosts']['with_simple_graph_items'] = true;
-		}
-		elseif ($this->hasInput('with_triggers')) {
-			$options['groups']['with_triggers'] = true;
-			$options['hosts']['with_triggers'] = true;
-		}
-		elseif ($this->hasInput('with_monitored_triggers')) {
-			$options['groups']['with_monitored_triggers'] = true;
-			$options['hosts']['with_monitored_triggers'] = true;
+		foreach (['with_applications', 'with_graphs', 'with_graph_prototypes', 'with_simple_graph_items',
+				'with_simple_graph_item_prototypes', 'with_triggers', 'with_monitored_triggers'] as $name) {
+			if ($this->hasInput($name)) {
+				$options['groups'][$name] = true;
+				$options['hosts'][$name] = true;
+
+				break;
+			}
 		}
 
 		$page_filter = new CPageFilter($options);
@@ -591,8 +577,11 @@ class CControllerPopupGeneric extends CController {
 			'dstact' => $this->getInput('dstact', ''),
 			'itemtype' => $this->getInput('itemtype', 0),
 			'multiselect' => $this->getInput('multiselect', 0),
+			'patternselect' => $this->getInput('patternselect', 0),
 			'parent_discoveryid' => $this->getInput('parent_discoveryid', 0),
-			'reference' => $this->getInput('reference', $this->getInput('srcfld1', 'unknown'))
+			'reference' => $this->getInput('reference', $this->getInput('srcfld1', 'unknown')),
+			'disableids' => $this->getInput('disableids', []),
+			'excludeids' => $this->getInput('excludeids', [])
 		];
 
 		$excludeids = $this->getInput('excludeids', []);
@@ -618,8 +607,9 @@ class CControllerPopupGeneric extends CController {
 		}
 
 		$option_fields_binary = ['enrich_parent_groups', 'monitored_hosts', 'noempty', 'normal_only', 'numeric',
-			'real_hosts', 'submit_parent', 'templated_hosts', 'with_applications', 'with_graphs', 'with_items',
-			'with_monitored_triggers', 'with_simple_graph_items', 'with_triggers', 'with_webitems', 'writeonly'];
+			'real_hosts', 'submit_parent', 'templated_hosts', 'with_applications', 'with_graphs',
+			'with_graph_prototypes', 'with_items', 'with_simple_graph_item_prototypes', 'with_monitored_triggers',
+			'with_simple_graph_items', 'with_triggers', 'with_webitems', 'writeonly'];
 		foreach ($option_fields_binary as $field) {
 			if ($this->hasInput($field)) {
 				$page_options[$field] = true;
@@ -733,7 +723,7 @@ class CControllerPopupGeneric extends CController {
 
 				$records = API::HostGroup()->get($options);
 				if (array_key_exists('enrich_parent_groups', $page_options)) {
-					$records = CPageFilter::enrichParentGroups($records, [
+					$records = enrichParentGroups($records, [
 						'real_hosts' => null
 					] + $options);
 				}
@@ -807,10 +797,13 @@ class CControllerPopupGeneric extends CController {
 			case 'items':
 			case 'item_prototypes':
 				$options = [
-					'output' => ['itemid', 'hostid', 'name', 'key_', 'flags', 'type', 'value_type', 'status', 'state'],
+					'output' => ['itemid', 'hostid', 'name', 'key_', 'flags', 'type', 'value_type', 'status'],
 					'selectHosts' => ['name'],
 					'preservekeys' => true
 				];
+				if ($this->source_table === 'items') {
+					$options['output'] = array_merge($options['output'], ['state']);
+				}
 
 				if ($page_options['parent_discoveryid']) {
 					$options['discoveryids'] = [$page_options['parent_discoveryid']];
@@ -848,7 +841,7 @@ class CControllerPopupGeneric extends CController {
 
 				// Resolve item names by default.
 				$records = array_key_exists('orig_names', $page_options)
-					? CArrayHelper::renameObjectsKeys($records, ['name' => 'name_expanded'])
+					? CArrayHelper::copyObjectsKeys($records, ['name' => 'name_expanded'])
 					: CMacrosResolverHelper::resolveItemNames($records);
 
 				CArrayHelper::sort($records, ['name_expanded']);
@@ -961,36 +954,15 @@ class CControllerPopupGeneric extends CController {
 				CArrayHelper::sort($records, ['name']);
 				break;
 
-			case 'screens2':
-				require_once dirname(__FILE__).'/../../include/screens.inc.php';
-
-				$options = [
-					'output' => ['screenid', 'name'],
-					'preservekeys' => true
-				];
-
-				if (array_key_exists('writeonly', $page_options)) {
-					$options['editable'] = true;
-				}
-
-				$records = API::Screen()->get($options);
-
-				foreach ($records as $item) {
-					if (array_key_exists('screenid', $page_options)
-							&& check_screen_recursion($page_options['screenid'], $item['screenid'])) {
-						unset($records[$item['screenid']]);
-					}
-				}
-
-				CArrayHelper::sort($records, ['name']);
-				break;
-
 			case 'drules':
 				$records = API::DRule()->get([
-					'output' => ['druleid', 'name']
+					'output' => ['druleid', 'name'],
+					'filter' => ['status' => DRULE_STATUS_ACTIVE],
+					'preservekeys' => true
 				]);
 
 				CArrayHelper::sort($records, ['name']);
+				$records = CArrayHelper::renameObjectsKeys($records, ['druleid' => 'id']);
 				break;
 
 			case 'dchecks':
@@ -1019,7 +991,7 @@ class CControllerPopupGeneric extends CController {
 
 			case 'scripts':
 				$options = [
-					'output' => API_OUTPUT_EXTEND,
+					'output' => ['scriptid', 'name', 'type', 'execute_on', 'command'],
 					'preservekeys' => true
 				];
 				if ($hostid === null) {
@@ -1046,6 +1018,29 @@ class CControllerPopupGeneric extends CController {
 			}
 		}
 
+		// Pattern selector uses names as ids so they need to be rewritten.
+		if ($page_options['patternselect']) {
+			switch ($this->source_table) {
+				case 'hosts':
+					foreach ($records as $hostid => $row) {
+						$records[$row['name']] = [
+							'host' => $row['name'],
+							'name' => $row['name'],
+							'id' => $row['name']
+						];
+						unset($records[$hostid]);
+					}
+					break;
+
+				case 'items':
+					foreach ($records as $itmeid => $row) {
+						$records[$row['name_expanded']] = ['itemid' => $row['name_expanded']] + $row;
+						unset($records[$itmeid]);
+					}
+				break;
+			}
+		}
+
 		$data = [
 			'title' => $this->popup_properties[$this->source_table]['title'],
 			'popup_type' => $this->source_table,
