@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -51,16 +51,16 @@ $fields = [
 	],
 	'pairs'           => [T_ZBX_STR, O_OPT, P_NO_TRIM,  null,                    null],
 	'steps'           => [T_ZBX_STR, O_OPT, P_NO_TRIM,  null,                    'isset({add}) || isset({update})', _('Steps')],
-	'authentication'  => [T_ZBX_INT, O_OPT, null,  IN('0,1,2'),             'isset({add}) || isset({update})'],
+	'authentication'  => [T_ZBX_INT, O_OPT, null,  IN('0,1,2,3'),             'isset({add}) || isset({update})'],
 	'http_user'       => [T_ZBX_STR, O_OPT, null,  null,
 		'(isset({add}) || isset({update})) && isset({authentication}) && ({authentication}=='.HTTPTEST_AUTH_BASIC.
-			' || {authentication}=='.HTTPTEST_AUTH_NTLM.
+			' || {authentication}=='.HTTPTEST_AUTH_NTLM.' || {authentication}=='.HTTPTEST_AUTH_KERBEROS.
 		')',
 		_('User')
 	],
 	'http_password'		=> [T_ZBX_STR, O_OPT, P_NO_TRIM, null,
 		'(isset({add}) || isset({update})) && isset({authentication}) && ({authentication}=='.HTTPTEST_AUTH_BASIC.
-			' || {authentication}=='.HTTPTEST_AUTH_NTLM.
+			' || {authentication}=='.HTTPTEST_AUTH_NTLM.' || {authentication}=='.HTTPTEST_AUTH_KERBEROS.
 		')',
 		_('Password')
 	],
@@ -711,6 +711,8 @@ if (isset($_REQUEST['form'])) {
 		}
 	}
 
+	$i = 1;
+
 	foreach($data['steps'] as $stepid => $step) {
 		$pairs_grouped = [
 			'query_fields' => [],
@@ -725,6 +727,7 @@ if (isset($_REQUEST['form'])) {
 			}
 			$data['steps'][$stepid]['pairs'] = $pairs_grouped;
 		}
+		$data['steps'][$stepid]['no'] = $i++;
 	}
 
 	// render view
