@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -366,22 +366,14 @@ abstract class CItemGeneral extends CApiService {
 						);
 					}
 
-					if ($fullItem['type'] == ITEM_TYPE_ZABBIX_ACTIVE) {
-						// Remove flexible and scheduling intervals and leave only the delay part.
-						$item['delay'] = $delay;
-					}
 					// If there are scheduling intervals or intervals with macros, skip the next check calculation.
-					elseif (!$has_macros && !$has_scheduling_intervals && $flexible_intervals
+					if (!$has_macros && !$has_scheduling_intervals && $flexible_intervals
 							&& calculateItemNextCheck(0, $delay_sec, $flexible_intervals, time()) == ZBX_JAN_2038) {
 						self::exception(ZBX_API_ERROR_PARAMETERS,
 							_('Item will not be refreshed. Please enter a correct update interval.')
 						);
 					}
 				}
-				elseif ($fullItem['type'] == ITEM_TYPE_ZABBIX_ACTIVE) {
-					// Remove flexible and scheduling intervals and leave only the delay part.
-					$item['delay'] = $delay;
-				}
 			}
 
 			// For non-numeric types, whichever value was entered in trends field, is overwritten to zero.
@@ -2049,7 +2041,7 @@ abstract class CItemGeneral extends CApiService {
 	}
 
 	/**
-	 * Validate depth and ammount of elements in the tree of the dependent items.
+	 * Validate depth and amount of elements in the tree of the dependent items.
 	 *
 	 * @param array  $dependent_items
 	 * @param string $dependent_items[<master_itemid>][]  List if the dependent item IDs ("false" for new items)
@@ -2235,7 +2227,7 @@ abstract class CItemGeneral extends CApiService {
 
 		if (array_key_exists('templateid', $data) && $data['templateid']) {
 			$rules['interfaceid'] = [
-				'type' => API_INT32, 'flags' => API_REQUIRED | API_NOT_EMPTY
+				'type' => API_ID, 'flags' => API_REQUIRED | API_NOT_EMPTY
 			];
 		}
 
