@@ -1119,6 +1119,13 @@ class CConfigurationExport {
 			'mediatypeids' => $mediatypeids,
 			'preservekeys' => true
 		]);
+
+		foreach ($this->data['mediaTypes'] as &$media_type) {
+			if ($media_type['type'] == MEDIA_TYPE_WEBHOOK) {
+				CArrayHelper::sort($media_type['parameters'], ['name']);
+			}
+		}
+		unset($media_type);
 	}
 
 	/**
